======
Maguey
======

Unofficial `Agave API`_ SDK for Python.

Installation
============

    $ pip install maguey

Getting Started
===============

.. code-block:: pycon

    >>> import maguey
    >>> stuff...

.. _Agave API: http://agaveapi.co/

License
=======

Maguey is licensed under the MIT license.
